import { Divider, Menu, Tooltip } from 'antd';
import React from 'react';

interface SiderMenuProps {
  collapsed: boolean;
  selectedKey: string;
  hangleMenuClick: (e: any) => void;
}

export default function SiderMenu({
  collapsed,
  selectedKey,
  hangleMenuClick,
}: SiderMenuProps) {
  const collapseStyle = collapsed
    ? { fontSize: '12px' }
    : { fontSize: '12px', paddingLeft: '52px' };

  const menuItems = [
    {
      key: 'toggle',
      icon: (
        <img
          src={
            !collapsed
              ? './icons/sider/menu_open.svg'
              : './icons/sider/menu.svg'
          }
          alt="toggle"
        />
      ),
      label: 'VORKOUT',
      style: { fontSize: '20px' },
    },
    {
      key: '/process-diagram',
      icon: (
        <img src="./icons/sider/process-diagram.svg" alt="process diagram" />
      ),
      label: <Tooltip title="Схемы процессов">Схемы процессов</Tooltip>,
    },
    {
      key: '/running-processes',
      icon: (
        <img
          src="./icons/sider/running-processes.svg"
          alt="running processes"
        />
      ),
      label: <Tooltip title="Запущенные процессы">Запущенные процессы</Tooltip>,
    },
    !collapsed
      ? {
          key: 'divider',
          label: <Divider />,
          style: {
            marginBottom: '-16px',
            marginTop: '-4px',
            cursor: 'default',
            width: '100%',
          },
          disabled: true,
        }
      : null,
    {
      key: 'sub1',
      icon: <img src="./icons/sider/settings.svg" alt="settings" />,
      label: 'Настройки',
      className: 'no-expand-icon',
      children: [
        {
          key: '/accounts',
          label: !collapsed ? (
            <Tooltip title="Учетные записи">Учетные записи</Tooltip>
          ) : (
            'Учетные записи'
          ),
          style: collapseStyle,
        },
        {
          key: '/events-list',
          label: !collapsed ? (
            <Tooltip title="Справочник событий">Справочник событий</Tooltip>
          ) : (
            'Справочник событий'
          ),
          style: collapseStyle,
        },
        {
          key: '/configuration',
          label: !collapsed ? (
            <Tooltip title="Конфигурация">Конфигурация</Tooltip>
          ) : (
            'Конфигурация'
          ),
          style: collapseStyle,
        },
      ],
    },
  ];

  return (
    <Menu
      theme="light"
      selectedKeys={[selectedKey]}
      mode="inline"
      onClick={hangleMenuClick}
      defaultOpenKeys={['sub1']}
      items={menuItems}
    />
  );
}
